<?php
/*
Plugin Name: User Login XML Enhanced
Description: Allow users to create an account and login to your website. Protects pages. XML Based.
Version: 1.0 based of User Login XML 3.1 by Mike Henken (http://michaelhenken.com/)
Author: René Mach
Author URI: http://www.tvbrowser.org/

*/

# get correct id for plugin
$thisfile=basename(__FILE__, ".php");

# register plugin
register_plugin(
	$thisfile, 
	'Front-End User Login Enhanced', 
	'1.6', 			
	'René Mach',	
	'http://www.tvbrowser.org/', 
	'Allow users to create an account and login to your website. Protects pages. Uses XML. (Based on Front-End User Login 3.1 by Mike Henken)', 
	'settings', 
	'user_login_admin' 
);

# hooks

//Adds 'Members Only' Check Box In edit.php
add_action('edit-extras','user_login_edit');

//Saves 'Members Only' checkbox selection when a page is saved
add_action('changedata-save','user_login_save');

//Filter Out The Content (Checks To See If Page Is Protected Or Not)
add_filter('content','perm_check');

//Launch Function 'user_login_check' before the template is loaded on the front-end
add_action('index-pretemplate','user_login_check');

//Add tab in admin navigation bar
add_action('nav-tab','makeNavTab');

//Test for side events
add_filter('content','testLoginFormLinks');

//Define Feul Settings File
define('FeulFile', GSDATAOTHERPATH  . 'user-login-enhanced.xml');

//Define User Login Plugin's plugins Folder (plugins/user-login/)
define('USERLOGINPATH', GSPLUGINPATH . 'user-login-enhanced/');

//Define User Login Plugin's plugins includes Folder (plugins/user-login/inc/)
define('LOGININCPATH', GSPLUGINPATH . 'user-login-enhanced/inc/');

//Define The User Data Storage Folder (data/site-users)
define('SITEUSERSPATH', GSDATAPATH . 'enhanced-site-users/');

//Define The User Data Storage Folder (data/site-users)
define('SITEUSERSGROUPPATH', GSDATAPATH . 'enhanced-site-groups/');

//Define path to the password reset user
define('RESETPASSWORDPATH', SITEUSERSPATH . 'resetpass/');

define('USERLOGINLANGPATH', USERLOGINPATH . 'lang/');

function testLoginFormLinks($content) {
	$register = @$_GET['register'];
	$forgotPass = @$_GET['forgotPass'];
	$forgotUser = @$_GET['forgotUser'];
	$changePW = @$_GET['changePW'];
	
	if (function_exists('return_i18n_languages')) {
	  	$langarr = return_i18n_languages();
	  	
	  	foreach($langarr as $language) {
	  		if(file_exists(USERLOGINLANGPATH.$language.'.php')) {
	  			include USERLOGINLANGPATH.$language.'.php';
	  			$lang = $language;
	  			break;
	  		}
	  	}
	}
	else {
		$lang = 'en';
		include USERLOGINLANGPATH.'en.php';
	}
	
	if(isset($register) && $register) {
		echo user_login_register($lang);
	}
	else if(isset($changePW)) {
		echo user_change_password($changePW,$i18n,$lang);
	}
	else if(isset($forgotPass) && $forgotPass) {
	        echo user_forgot_password($i18n);
	}
	else if(isset($forgotUser) && $forgotUser) {
		echo user_forgot_name($i18n);
	}

	
	return $content;
}

function makeNavTab()
{
	$plugin = 'user_login_enhanced';
	$class = '';
	$txt = '<em>U</em>ser Management';
	if (@$_GET['id'] == @$plugin) {
		$class='class="tabSelected"';
	}
	echo '<li><a href="load.php?id='.$plugin.'" '.$class.' >';
	echo $txt;
	echo "</a></li>";
}	

//Include Feul class
require_once(USERLOGINPATH.'class/Feul.php');

/** 
* Check If Page Is Protected Or Not. 
* Then, Either Blocks Access Or Shows Content, Depending On If Logged In Or Not
*
* @param string $content the content for the page.. It comes through the content filter (hook)
*
* @return string content or page protected message
*/  
function perm_check($content)
{
	$Feul = new Feul;
	if($Feul->checkPerm())
	{
		return $content;
	}
	else
	{
		return $Feul->getData('protectedmessage');
	}
}

/**
* Deprecated user getCurrentUserGroups() instead to get array of users groups.
*/
function getCurrentUserGroup() {
	return 'Use PHP function getCurrentUserGroups() instead to get array of users groups.';
}

/**
*
* @return string of the current user group
*/
function getCurrentUserGroups() {
	if(isset($_SESSION['LoggedIn']))
	{
		$Feul = new Feul;
		return explode(';',$Feul->getUserData($_SESSION['Username'],'Group'));
	}

	return array('Unauthorized');
}


/** 
* Proccess Admin User Login Settings and various contional statements related to this plugin.
*
* @return string content or page protected message
*/  
function user_login_admin()
{
	$Feul = new Feul;
	if(isset($Feul->first) && !isset($_GET['settings']))
	{
		echo '<div class="error"><a href="load.php?id=user_login_enhanced&settings">Click Here</a> to make initial settings.</div>';
	}
?>	
	<link rel="stylesheet" type="text/css" href="../plugins/user-login-enhanced/css/admin_style.css" />
	<div style="width:100%;margin:0 -15px -15px -10px;padding:0px;">
		<h3  class="floated">Front-End User Login Plugin</h3>
		<div class="edit-nav clearfix">
			<p>
				<a href="load.php?id=user_login_enhanced&help">Help</a>
				<a href="load.php?id=user_login_enhanced&settings">Settings</a>
				<a href="load.php?id=user_login_enhanced&email=yes">Email Users</a>
				<a href="load.php?id=user_login_enhanced&manage_groups=yes">Manage Groups</a>
				<a href="load.php?id=user_login_enhanced&manage=yes">Manage Users</a>
			</p>
		</div>
	</div>
	</div>
	<div class="main" style="margin-top:-10px;">
	<?php
	if(isset($_GET['email']))
	{
		if(isset($_POST['send-email']))
		{	
			if(isset($_POST['send_all']))
			{
				$dir = SITEUSERSPATH."*.xml";
				// Make Edit Form For Each User XML File Found
				foreach (glob($dir) as $file) 
				{
					$xml = simplexml_load_file($file) or die("Unable to load XML file!");
					$Feul->processEmailUser($xml->EmailAddress, $xml->Username, $_POST['email'], $_POST['subject'], $_POST['post-email-message']);
				}
				echo '<div class="updated">Emails Successfully Sent</div>';
			}
			else
			{
				$emails = $Feul->processEmailUser($_POST['email_to'], null, $_POST['email'], $_POST['subject'], $_POST['post-email-message']);
				if($emails != false)
				{
					echo '<div class="updated">Email Successfully Sent</div>';
				}
			}
		}
	global $text_area_name;
	$text_area_name = 'post-email-message';
	?>
		<h3>Send Email To Users</h3>
		<form method="post" action="load.php?id=user_login_enhanced&email=yes&send-email=yes">
			<p>
				<label for="from-email">"From" Email Address</label>
				<input type="text" name="email" class="text" value="<?php echo $Feul->getData('email'); ?>" />
			</p>
			<div style="padding:10px;margin-bottom:15px;background-color:#f6f6f6;">
			<p>
				<label style="font-size:15px;padding-bottom:3px;">Check This Box To Send To All Users</label>
				<input type="checkbox" name="send_all" />
			</p>
			<p style="margin-top:-10px; margin-bottom:10px;">
				<label style="font-size:18px;color:red;">OR:</label>
			</p>
			<p>
				<label for="subject" style="font-size:15px;padding-bottom:3px;">Enter Recipitent's email address(s) here. Seperated by comma</label>
				<input type="text" name="email_to" class="text" value="" />
			</p>
			</div>
			<p>
				<label for="subject">Email Subject</label>
				<input type="text" name="subject" class="text" value="" />
			</p>
			<label for="email-message">Message:</label>
			<textarea name="post-email-message"></textarea>
			<?php include(USERLOGINPATH . 'ckeditor.php'); ?>
			<input type="submit" class="submit" name="send-email" value="Submit" />
		</form>
	<?php
	}
	elseif(isset($_GET['settings']))
	{
		if(isset($_POST['Feul_settings_form']))
		{
			$submit_settings = $Feul->processSettings();
			if($submit_settings == true)
			{
				echo '<div class="updated">Front-End User Login Settings Succesfully Edited</div>';
			}
			else
			{
				echo '<div class="error">Settings Could Not Be Saved!</div>';
			}
		}
		?>			
			<form method="post">
			<div class="main" style="margin-top:-10px;">
				<h2>Email Settings</h2>
				<p>
					<label>Edit Registration "From" Email Address</label>This is the "From" address that shows in the "Registration Email" the user gets upon registering:<br/>
					<input type="text" name="post-from-email" class="text full" value="<?php echo $Feul->getData('email'); ?>" />
				</p>
				
			</div>
			<div class="main" style="margin-top:-10px;">
			<h2>CSS &amp; Protected Message</h2>
				<p>
					<label>Edit Login Container CSS</label>
					<textarea name="post-login-container" class="full" style="height:300px;">
						<?php echo $Feul->LoginCss; ?>
					</textarea>
				</p>
				<p>
					<label>Edit Welcome Box CSS</label>
					<textarea name="post-welcome-box" class="full" style="height:300px;">
						<?php echo $Feul->WelcomeCss; ?>
					</textarea>
				</p>
				<p>
					<label>Edit Register Box CSS</label>
					<textarea name="post-register-box" class="full" style="height:300px;">
						<?php echo $Feul->RegisterCss; ?>
					</textarea>
				</p>
				<p>
					<label>Edit Protected Message</label>
					<textarea name="post-protected-message">
						<?php global $text_area_name; $text_area_name = 'post-protected-message'; echo $Feul->ProtectedMessage; ?>
					</textarea>
					</p>
				<?php include(USERLOGINPATH . 'ckeditor.php'); ?>
				<p>
					<input type="submit" name="Feul_settings_form" class="submit" value="Submit" />
				</p>
			</form>
			<br/>
			<?php
	}
	elseif(isset($_GET['edit_user']))
	{
		if(isset($_POST['Feul_edit_user']))
		{
			if($_POST['old_name'] != $_POST['usernamec'])
			{
				$change_name = $_POST['usernamec'];
			}
			else
			{
				$change_name = null;
			}

			$posted_password = $_POST['nano'];	
			if(isset($_POST['userpassword']))
			{
				$change_pass = $_POST['userpassword'];
			}
			else
			{
				$change_pass = null;
			}
			
			$groups = "";
			
			foreach($_POST['groupc'] as $selectedGroup) {
				$groups = $groups.$selectedGroup.';';
			}
			
			if(strlen(trim($groups)) == 0) {
				$groups = "Users";
			}
			else {
				$groups = trim(substr($groups,0,strlen($groups)-1));
			}
			
			$Feul->processEditUser($_POST['old_name'], $groups, $_POST['fullnamec'], $posted_password, $_POST['useremail'], $change_pass, $change_name);

			if($change_name != null)
			{
				print '<meta http-equiv="refresh" content="0;url=load.php?id=user_login_enhanced&edit_user='.$change_name.'">';
			}
		}
		editUser($_GET['edit_user']);
	}
	elseif(isset($_GET['edit_group']))
	{
		if(isset($_POST['Feul_edit_group']))
		{
			$Feul->processEditGroup($_POST['groupID'], $_POST['groupdesc']);
		}
		editGroup($_GET['edit_group']);
	}
	elseif(isset($_GET['help']))
	{
	?>
		<h2>Plugin Information:</h2>

		<h4>Functions</h4>

		<p>
			<label>Display Login Form:</label>
			<?php highlight_string('<?php echo show_login_box(\'en\'); ?>'); ?>
		</p>

		<p>
			<label>Display Welcome Message:</label>
			This is displayed if the user is logged in. It consists of "Welcome Username" and a logout link.<br/>
			<?php highlight_string('<?php echo welcome_message_login(\'en\'); ?>'); ?>
		</p>

		<p>
			<label>Display Register Form:</label>
			<?php highlight_string('<?php user_login_register(\'en\'); ?>'); ?>
		</p>
		<p>Note: If you change the 'en' to 'de' you will get German formulars. You can add translations to the lang directory of the Front-End User Login Enhanced Plugin. Translations will only change the Front-End, the Back-End will stay English.
		</p>

		<h4>Showing Content To Only Logged In Users</h4>
		<ol>
			<li>You could block access to a particular page by choosing "Members Only" in the "Page Options" for that page.<br/>
				If a page is "Members Only", when a user is not logged in they will see the "Protected Message" which can be changed <a href="load.php?id=user_login_enhanced&settings">here</a>
			</li><br/>
			<li>
				If you would like "Members Only" content in your template you will have to use a little php. <br/> Below is an example of how to display "Hello World" to only logged in users.<br/>
<pre>
<?php highlight_string('<?php if(!empty($_SESSION[\'LoggedIn\']))	{ ?>'); ?>
	Helo World
<?php highlight_string('<?php } ?>'); ?>
</pre>
			</li>
		</ol>

		<h4>Further Help &amp; Support</h4>
		<p>
			If you run into any bugs/errors or need any assitance please visit the support forums <a href="http://get-simple.info/forum/topic/2342/front-end-user-login-plugin-xml-ver-25/">Here</a>
		</p>
		</div>
	<?php
	}
	elseif(isset($_GET['manage_groups']))
	{
		if(isset($_GET['addgroup']))
		{		
			$Add_User = $Feul->processAddGroupAdmin($_POST['groupnamec'],$_POST['groupdesc']);
			if($Add_User == false) 
			{
				echo '<div class="error">Group Name Already Taken</div>';
			}
			else
			{
				echo '<div class="updated">Group Successfully Added</div>';
			}
		}
		elseif (isset($_GET['deletegroup'])) 
		{
			$deleteUser = $Feul->deleteGroup($_GET['deletegroup']);
			
			if($deleteUser == true)
			{
				echo '<div class="updated" style="display: block;">'.$_GET['deletegroup'].' Has Been Successfully Deleted</div>';
			}
			else
			{
				echo '<div class="updated" style="display: block;"><span style="color:red;font-weight:bold;">ERROR!!</span> - Unable To Delete Group</div>';
			}
		}
		manageGroups();
	}
	else
	{
		if(isset($_GET['manage']))
		{
			if(isset($_GET['adduser']))
			{		
				$Add_User = $Feul->processAddUserAdmin($_POST['usernamec'],$_POST['groupc'],$_POST['fullnamec'],$_POST['userpassword'],$_POST['useremail']);
				if($Add_User == false) 
				{
					echo '<div class="error">User already exists or email already used</div>';
				}
				else
				{
					echo '<div class="updated">User Successfully Added</div>';
				}
			}
			elseif (isset($_GET['deleteuser'])) 
			{
				$deleteUser = $Feul->deleteUser($_GET['deletename']);
				
				if($deleteUser == true)
				{
					echo '<div class="updated" style="display: block;">'.$_GET['deletename'].' Has Been Successfully Deleted</div>';
				}
				else
				{
					echo '<div class="updated" style="display: block;"><span style="color:red;font-weight:bold;">ERROR!!</span> - Unable To Delete User</div>';
				}
			}
		}
		manageUsers();
	}
}

function getUserGroup($id) {
	return 'Use PHP function getUserGroups($id) instead to get array with users groups.';
}

function getUserGroups($id) {
  $Feul = new Feul;
  
  if($Feul->userExists($id)) {
  	return explode(';',$Feul->getUserData($id,'Group'));
  }
  
  return array('Unknown');
}

function getUserMail($id) {
  $Feul = new Feul;
  
  if($Feul->userExists($id)) {
  	return $Feul->getUserData($id,'EmailAddress');
  }
  
  return 'Unknown';
}

function getAllUsers() {
	$Feul = new Feul;
	return $Feul->getAllUsers();
}

function getEmailForFullName($fullName) {
	foreach(getAllUsers() as $user) {
		if(strcmp($fullName,$user->FullName) == 0) {
			return $user->EmailAddress;
		}
	}
	
	return '';
}

function getUserForEmail($email) {
	foreach(getAllUsers() as $user) {
		if(strcmp($email,$user->EmailAddress) == 0) {
			return $user->Username;
		}
	}
	
	return '';
}

function getUserFullName($id) {
  $Feul = new Feul;
  
  if($Feul->userExists($id)) {
  	return $Feul->getUserData($id,'FullName');
  }
  
  return 'Unknown';
}

function manageGroups()
{
	$Feul = new Feul;
	$groups = $Feul->getAllGroups();
	
	?>
	<div id="profile" class="hide-div section" style="display:none;margin-top:-30px;">
		<form method="post" action="load.php?id=user_login_enhanced&manage_groups=yes&addgroup=yes">
			<h3>Add New User</h3>
			<div class="leftsec">
				<p>
					<label for="groupnamec" >Group name:</label>
					<input class="text" id="groupnamec" name="groupnamec" type="text" value="" />
				</p>
			</div>
			<div class="rightsec">
				<p>
					<label for="groupdesc" >Description:</label>
					<input class="text" id="groupdesc" name="groupdesc" type="text" value="""/>
				</p>
			</div>
			<div class="clear"></div>
			<p id="submit_line" >
				<span>
					<input class="submit" type="submit" name="submitted" value="Add New Group" />
				</span> &nbsp;&nbsp;<?php i18n('OR'); ?>&nbsp;&nbsp; 
				<a class="cancel" href="#"><?php i18n('CANCEL'); ?></a>
			</p>
		</form>
	</div>
	<h3 class="floated">Group Management</h3>
		<div class="edit-nav clearfix">
			<p>
				<a href="#" id="add-group">Add New Group</a>
			</p>
		</div>
		<?php
		if($groups != false) 
		{ 
		?>
			<table class="highlight" style="width:900px">
				<tr>
					<th>Name</th>
					<th>Description</th>
				<tbody>
			<?php
			// Make Edit Form For Each Group XML File Found
			foreach ($groups as $row)
			{
				if(strcmp($row,"Admin") == 0)
				{
					$Groupname = $row;
					$Description = "Font end user login enhanced Administrator group. (Access to all pages.)";
					$editable = false;
				}
				elseif(strcmp($row,"Users") == 0)
				{
					$Groupname = $row;				
					$Description = "Font end user login enhanced default users group.";
					$editable = false;
				}
				elseif(strcmp($row,"Unauthorized") == 0)
				{
					$Groupname = $row;				
					$Description = "Group for all not logged in users or users that are logged in but should not have any rights.";
					$editable = false;
				}
				else
				{
					$Groupname = $row->Groupname;
					$Description = $row->Description;
					$editable = true;
				}

				//Below is the Group Data
				?>	
				<tr>
					<td>
						<?php
							if($editable) {
								echo '<a href="load.php?id=user_login_enhanced&edit_group='.$Groupname.'">'.$Groupname.'</a>';
							}
							else {
								echo $Groupname;
							}
						?>
							
					</td>
					<td>
					       <?php echo $Description; ?>
					</td>
				</tr>
			<?php } ?>
				</tbody>
			</table>
		<?php 
		}
		?>
	<script type="text/javascript">
		
		/*** Show add-user form ***/
		$("#add-group").click(function () {
			$(".hide-div").show();
			$("#add-group").hide();
		});
		
		/*** Hide user form ***/
		$(".cancel").click(function () {
			$(".hide-div").hide();
			$("#add-group").show();
		});
	</script>
	<?php
}

function manageUsers()
{
	$Feul = new Feul;
	$users = $Feul->getAllUsers();
	$groups = $Feul->getAllGroupNames();
	
		?>
		<div id="profile" class="hide-div section" style="display:none;margin-top:-30px;">
			<form method="post" action="load.php?id=user_login_enhanced&manage=yes&adduser=yes">
				<h3>Add New User</h3>
				<div class="leftsec">
					<p>
						<label for="usernamec" >User name:</label>
						<input class="text" id="usernamec" name="usernamec" type="text" value="" />
					</p>
				</div>
				<div class="leftsec">
					<p>
						<label for="groupc" >Groups:</label>
						<select class="text" id="groupc" name="groupc" type="text">
							<?php
								foreach($groups as $groupNames) {
									if($groupNames == "Users") {
										echo "<option selected>".$groupNames."</option>";
									}
									else {
										echo "<option>".$groupNames."</option>";
									}
								}
							?>
						</select>
					</p>
				</div>
				<div class="leftsec">
					<p>
						<label for="fullnamec" >Full name:</label>
						<input class="text" id="fullnamec" name="fullnamec" type="text" value="" />
					</p>
				</div>
				<div class="rightsec">
					<p>
						<label for="useremail" >Email:</label>
						<input class="text" id="useremail" name="useremail" type="text" value="" />
					</p>
				</div>
				<div class="leftsec">
					<p>
						<label for="userpassword" >Password:</label>
						<input autocomplete="off" class="text" id="userpassword" name="userpassword" type="text" value="" />
					</p>
				</div>
				<div class="clear"></div>
				<p id="submit_line" >
					<span>
						<input class="submit" type="submit" name="submitted" value="Add New User" />
					</span> &nbsp;&nbsp;<?php i18n('OR'); ?>&nbsp;&nbsp; 
					<a class="cancel" href="#"><?php i18n('CANCEL'); ?></a>
				</p>
			</form>
		</div>
		<h3 class="floated">User Management</h3>
		<div class="edit-nav clearfix">
			<p>
				<a href="#" id="add-user">Add New User</a>
			</p>
		</div>
		<?php
		if($users != false) 
		{ 
		?>
			<table class="highlight" style="width:900px">
				<tr>
					<th>Name</th>
					<th>Groups</th>
					<th>Full name</th>
					<th>Email</th>
				<tbody>
			<?php
			// Make Edit Form For Each User XML File Found
			foreach ($users as $row)
			{
				$Username = $row->Username;
				$Group = "";
				
				$i = 0;
				
				foreach(explode(";",$row->Group) as $userGroup) {
					$Group = $Group.$userGroup.", ";
					
					$i++;
					
					if($i % 3 == 0) {
						$Group = $Group.'<br>';
					}
				}
				
				if(strpos($Group,'<br>') == strlen($Group)-4) {
					$Group = substr($Group,0,strlen($Group)-4);
				}
				
				$Group = trim($Group);
				$Group = trim(substr($Group,0,strlen($Group)-1));
				
				$Fullname = $row->FullName;
				$EmailAddress = $row->EmailAddress;

				//Below is the User Data
				?>	
				<tr>
					<td>
						<a href="load.php?id=user_login_enhanced&edit_user=<?php echo $Username; ?>">
						<?php echo $Username; ?></a>
					</td>
					<td>
					       <?php echo $Group; ?>
					</td>
					<td>
					       <?php echo $Fullname; ?>
					</td>
					<td>
						<?php echo $EmailAddress; ?>
					</td>
				</tr>
			<?php } ?>
				</tbody>
			</table>
		<?php 
		}
		elseif($users == false)
		{
			echo '<p><strong>No Users Exist</strong></p>';
		}
		?>
	<script type="text/javascript">
		
		/*** Show add-user form ***/
		$("#add-user").click(function () {
			$(".hide-div").show();
			$("#add-user").hide();
		});
		
		/*** Hide user form ***/
		$(".cancel").click(function () {
			$(".hide-div").hide();
			$("#add-user").show();
		});
	</script>
	<?php
}

function editGroup($id)
{
	$id = urldecode($id);
	$Feul = new Feul;
	?>
	<h3>Group Information</h3>
	<form method="post" action="load.php?id=user_login_enhanced&edit_group=<?php echo $id; ?>">
		<div class="leftsec">
			<p>
				<label for="groupnamec" >Name:</label>
				<input class="text" id="groupnamec" name="groupnamec" type="text" value="<?php echo $id?>" disabled/>
			</p>
		</div>
		<div class="rightsec">
			<p>
				<label for="groupdesc" >Description:</label>
				<input class="text" id="groupdesc" name="groupdesc" type="text" value="<?php echo $Feul->getGroupDescription($id); ?>" />
			</p>
		</div>
		<div class="clear"></div>
		<p id="submit_line">
			<span>
				<input class="submit" type="submit" name="Feul_edit_group" value="Submit Changes" /> 
				
				<?php
					if(!$Feul->groupIsUsed($id)) {
					echo '&nbsp;&nbsp;Or&nbsp;&nbsp; <a class="cancel" style="color: #D94136;text-decoration:underline;cursor:pointer" ONCLICK="decision(\'Are You Sure You Want To Delete '.$id. '?\',\'load.php?id=user_login_enhanced&manage_groups=yes&deletegroup='.$id.'\')">Delete Group</a>';
					}
				?>
				
				<input type="hidden" name="groupID" value="<?php echo $id; ?>"/>
			</span>
		</p>
	</form>
	<script type="text/javascript">
		/*** Confirm the user wants to delete a group ***/
		function decision(message, url){
			if(confirm(message)) location.href = url;
		}
	</script>
	<?php
}

function editUser($id)
{
	$id = urldecode($id);
	$Feul = new Feul;
	?>
	<h3>User Information</h3>
	<form method="post" action="load.php?id=user_login_enhanced&edit_user=<?php echo $id; ?>">
		<div class="leftsec">
			<p>
				<label for="usernamec" >Name:</label>
				<input class="text" id="usernamec" name="usernamec" type="text" value="<?php echo $Feul->getUserDataID($id,'Username'); ?>" />
			</p>
		</div>
		<div class="leftsec">
			<p>
				<label for="groupc" >Groups:</label>
				<select class="text" id="groupc" name="groupc[]" type="text" multiple size=4>
						<?php
							$groups = explode(";", $Feul->getUserDataID($id,'Group'));
														
							foreach($Feul->getAllGroupNames() as $group) {
								echo '<option ';
								
								foreach($groups as $userGroup) {
									if($group == $userGroup) {
										echo ' selected';
									}
								}
								
								echo '>'.$group.'</option>';
							}
						?>
				</select>
			</p>
		</div>
		<div class="leftsec">
			<p>
				<label for="fullnamec" >Full Name:</label>
				<input class="text" id="fullnamec" name="fullnamec" type="text" value="<?php echo $Feul->getUserDataID($id,'FullName'); ?>" />
			</p>
		</div>
		<div class="rightsec">
			<p>
				<label for="useremail" >Email:</label>
				<input class="text" id="useremail" name="useremail" type="text" value="<?php echo $Feul->getUserDataID($id,'EmailAddress'); ?>" />
			</p>
		</div>
		<div class="leftsec">
			<p>
				<label for="userpassword" >Change Password:</label>
				<input autocomplete="off" class="text" id="userpassword" name="userpassword" type="text" value="" />
			</p>
		</div>
		<div class="clear"></div>
		<p id="submit_line">
			<span>
				<input class="submit" type="submit" name="Feul_edit_user" value="Submit Changes" /> &nbsp;&nbsp;Or&nbsp;&nbsp; <a class="cancel" style="color: #D94136;text-decoration:underline;cursor:pointer" ONCLICK="decision('Are You Sure You Want To Delete <?php echo $Feul->getUserDataID($id,'Username'); ?>?','load.php?id=user_login_enhanced&manage=yes&deleteuser=<?php echo $id; ?>&deletename=<?php echo $Feul->getUserDataID($id,'Username'); ?>')">Delete User</a>
				<input type="hidden" name="nano" value="<?php echo $Feul->getUserDataID($id,'Password'); ?>"/>
				<input type="hidden" name="old_name" value="<?php echo $Feul->getUserDataID($id,'Username'); ?>"/>
				<input type="hidden" name="userID" value="<?php echo $id; ?>"/>
			</span>
		</p>
	</form>
	<script type="text/javascript">
		/*** Confirm the user wants to delete a user ***/
		function decision(message, url){
			if(confirm(message)) location.href = url;
		}
	</script>
	<?php
}


/*******
Function To: 
Displays Login Box On Front-End Of Website
*******/
function show_login_box($lang = 'en')
{
	$register = @$_GET['register'];
	$forgotPass = @$_GET['forgotPass'];
	$forgotUser = @$_GET['forgotUser'];
	
        if(!isset($register) && !isset($forgotPass) && !isset($forgotUser)) {
        	if(is_file(USERLOGINLANGPATH.$lang.'.php')) {
        		include USERLOGINLANGPATH.$lang.'.php';
        	}
	  	else {
	  		include USERLOGINLANGPATH.'en.php';
	  	}
	
		$Feul = new Feul;
		//If The User Is Not Logged In - Display Login Box - If They Are Logged In, Display Nothing
		if(!isset($_SESSION['LoggedIn']))
		{	
			echo $Feul->getData('logincontainer');
			$is_loggedIn = $Feul->checkLogin();
			//HTML Code For Login Container
			?>
				
			<div class="loginform">
				<h2>Login</h2>
				<?php
					if(isset($_POST['username']) && isset($_POST['password']) && isset($_POST['login-form']) && $is_loggedIn == false)
					{
						echo '<div class="error">'.$i18n['USERNOTFOUND'].'</div>';
					}
				?>
				<form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" name="loginform" id="loginform" >
					<p>
						<label for="username" ><?php echo $i18n['USERNAME']; ?></label>
						<input type="text" name="username" required/>
					</p>
					<p>
						<label for="password"><?php echo $i18n['PASSWORD']; ?></label>
						<input type="password" name="password" required/>
					</p>
					<p>
						<input type="submit" class="user_login_submit" value="<?php echo $i18n['LOGIN'];?>"/>
					</p>
					<input type="hidden" name="login-form" value="login" />
				</form>
				<div style="clear:both"></div>
			</div>
			<?php
		
			if(strpos(basename($_SERVER['REQUEST_URI']),'?') === false) {
				$code = '?';
			}
			else {
				$code = '&';
			}
		
			echo '<p><a href="'.basename($_SERVER['REQUEST_URI']).$code.'register=1">'.$i18n['REGISTER'].'</a><br>';
			echo '<a href="'.basename($_SERVER['REQUEST_URI']).$code.'forgotPass=1">'.$i18n['FORGOTPASS'].'</a><br>';
			echo '<a href="'.basename($_SERVER['REQUEST_URI']).$code.'forgotUser=1">'.$i18n['FORGOTUSER'].'</a></p>';
				
		}
	}
}

/*******
Function To: 
Show Welcome Message If User Is Logged In - If Not Logged In, Display nothing
*******/
function welcome_message_login($lang = 'en')
{
	if(is_file(USERLOGINLANGPATH.$lang.'.php')) {
		include USERLOGINLANGPATH.$lang.'.php';
	}
  	else {
  		include USERLOGINLANGPATH.'en.php';
  	}
	
	global $SITEURL;
	$Feul = new Feul;
	if(isset($_SESSION['LoggedIn']))
	{
		$name  = $_SESSION['Username'];
		//Display Welcome Message
		$welcome_box = '<div class="user_login_welcome_box_container"><span class=\"user-login-welcome-label\">'.$i18n['WELCOME'].'</span>'.$name.'</div>';

		//Display Logout Link
		$logout_link = '<p><a href="'.$SITEURL.'?logout=yes" class="user-login-logout-link">'.$i18n['LOGOUT'].'</a></p>';
		echo $Feul->getData('welcomebox').$welcome_box.$logout_link ;
	}
}

/*******
Function To: 
Check If User Is Logged In - Also Starts Session And Connects To Database
*******/
function user_login_check()
{
	$Feul = new Feul;
	$Feul->checkLogin();
	/* 
	If Logout Link Is Clicked:
	Log Client Out (End Session) 
	*/
	if(isset($_GET['logout']))
	{
		if(!empty($_SESSION['LoggedIn']) && !empty($_SESSION['Username']))
		{
			$_SESSION = array(); 
			session_destroy();
		}
	}	
}


/*******
Function To: 
Register Form And Processing Code - Display's And Processes Register Form
*******/
function user_login_register($lang = 'en')
{
	if(is_file(USERLOGINLANGPATH.$lang.'.php')) {
		include USERLOGINLANGPATH.$lang.'.php';
	}
  	else {
  		include USERLOGINLANGPATH.'en.php';
  	}
  	
	global $SITEURL;
	$Feul = new Feul;
	$error = '';
	$showForm = true;
	//If User Is Not Logged In
	if(!isset($_SESSION['LoggedIn']))
	{
		if(isset($_POST['register-form']))
		{
			//If Register Form Was Submitted
			if($_POST['username'] != '' && $_POST['fullname'] != '' && $_POST['password'] != '' && strpos($_POST['email'],'@') !== false)
			{
				$addUser = $Feul->processAddUserAdmin($_POST['username'], 'Users', $_POST['fullname'], $_POST['password'], $_POST['email']);
				if($addUser == true)
				{
					echo '<div class="success">'.$i18n['REGOK'].$_POST['username'].'</div>';
					$Feul->checkLogin(true, $_POST['username'], $_POST['password']);
					//Send Email
					$to  = $_POST['email'];
					$Username = $_POST['username'];
					$Fullname = $_POST['fullname'];
					$chosen_password = $_POST['password'];

					// subject
					$subject = 'Your New Account ('.$Username.') Is Setup!';

					// message
					$message = '
					<html>
					<head>
					<title>Your New Account Is Setup!</title>
					</head>
					<body>
					<h2><strong>Below is your login information:</strong></h2><br/><br/>
					<strong>Username: </strong>'.$Username.'<br/>
					<strong>Full name: </strong>'.$Fullname.'<br/>
					<strong>Password: </strong>'.$chosen_password.'<br/>
					<br/>
					<a href="'.$SITEURL.'">Click Here To Visit Website</a>
					</body>
					</html>
					';

					// To send HTML mail, the Content-type header must be set
					$headers  = 'MIME-Version: 1.0' . "\r\n";
					$headers .= 'Content-type: text/html; charset=iso-8859-1' . "\r\n";

					// Additional headers
					//$headers .= 'To: Mary <mary@example.com>, Kelly <kelly@example.com>' . "\r\n";
					$headers .= 'From: New Account <'.$Feul->getData('email').'>' . "\r\n";
					//$headers .= 'Cc: birthdayarchive@example.com' . "\r\n";
					//$headers .= 'Bcc: birthdaycheck@example.com' . "\r\n";

					// Mail it
					
					$success = mail($to, $subject, $message, $headers);
					if(!$success)
					{
						$error = '<div class="error">'.$i18n['NOEMAILSEND'].'</div>';
					}
					$showForm = false;
				}
				else
				{
					echo '<div class="error">'.$i18n['USEREXISTS'].'</div>';
				}
			}
			else
			{
				$error = '<div class="error">Please fill in the required fields</div>';
			}
		}
		if($showForm) {
			echo $Feul->getData('registerbox');
			?>
				
				<h2 class="register_h2"><?php echo $i18n['REGISTER'];?></h2>
				
				<?php
					if(isset($_POST['email']) && strpos($_POST['email'],'@') === false) {
						echo '<p>'.$i18n['ONLYVALIDMAIL'].'</p>';
					}
				?>
				
				<form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" name="registerform" id="registerform">
					<p>
						<label for="username" class="required" ><?php echo $i18n['USERNAME'];?></label>
						<input type="text" required name="username" id="name" />
					</p>
					<p>
						<label for="fullname" class="required" ><?php echo $i18n['FULLNAME'];?></label>
						<input type="text" required name="fullname" id="fullname" />
					</p>
					<p>
						<label for="email" class="required" ><?php echo $i18n['EMAIL'];?></label>
						<input type="text" required name="email" id="email" />
					</p>
					<p>
						<label for="password" class="required" ><?php echo $i18n['PASSWORD'];?></label>
						<input type="password" required name="password" id="password" />
					</p>
					<p>
						<input type="submit" name="register" id="register" value="<?php echo $i18n['REGISTER'];?>" />
						<input type="hidden" name="register-form" value="yes" />
					</p>
				</form>
			<?php
		}
	}	
}

function user_change_password($changePW,$i18n,$lang) {
	if(isset($_POST['changepass-form'])) {
		$user = $_POST['user-form'];
		$userCheck = $_POST['forgotpassuser'];
		
		if(strcmp($user,$userCheck) == 0) {
			$newPass = $_POST['forgotpassPW'];
			
			$Feul = new Feul;
			
			$Feul->processEditUser($user, $Feul->getUserData($user,'Group'), $Feul->getUserData($user,'FullName'), $Feul->getUserData($user,'Password'), $Feul->getUserData($user,'EmailAddress'), $newPass, $user);
			
			echo '<p>'.$i18n['PASSCHANGED'].'</p>';
		}
		else {
			echo '<p>'.$i18n['NOVERIFICATION'].'</p>';
		}
	}
	else {
		$file = RESETPASSWORDPATH.$changePW;
		$error = true;
		
		if(is_file($file)) {
			$xml = getXML($file);
			
			if(isset($xml->Time)) {
				$diff = (int) time() - intval($xml->Time);
			
				if($diff > 21600) {
					echo '<p>'.$i18n['TIMELIMIT'].'</p>';
				}
				else {
					?>
					<h2 class="register_h2"><?php echo $i18n['FORGOTPASS'];?></h2>
					<p></p>
					<form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" name="changepassform" id="forgotpassform">
						<p><?php echo $i18n['NEWPASSINFO']; ?></p>
						<p>
							<label for="forgotpassuser" class="required" ><?php echo $i18n['USERNAME'];?></label>
							<input type="text" required name="forgotpassuser" id="forgotpassuser" />
						</p>
						<p>
							<label for="forgotpassPW" class="required" ><?php echo $i18n['NEWPASS'];?></label>
							<input type="password" required name="forgotpassPW" id="forgotpassPW" />
						</p>
						<p>
							<input type="submit" name="changepass" id="changepass" value="<?php echo $i18n['SEND'];?>" />
							<input type="hidden" name="changepass-form" value="yes" />
							<input type="hidden" name="user-form" value="<?php echo $xml->User; ?>" />
						</p>
					</form>

					<?php
				}
			
				$error = false;
			}
		
			unlink($file);
		}
	
		if($error) {
			echo '<p>'.$i18n['NOACCESS'].'</p>';
		}
	}
}

function user_forgot_name($i18n) {
	$showForm = true;
  	global $SITEURL;
  	
  	//If User Is Not Logged In
	if(!isset($_SESSION['LoggedIn']))
	{
		if(isset($_POST['forgotuser-form']))
		{
			if(isset($_POST['emailforgotuser']))
			{
				$user = getUserForEmail($_POST['emailforgotuser']);
				
				if(strlen($user) > 0) {
					//Send Email
					$to  = $_POST['emailforgotuser'];

					// subject
					$subject = 'You have requested your username for '.$SITEURL;

					// message
					$message = "Hello ".$user.",\n\nthat is your username.";
					
					// Mail it
					$success = mail($to, $subject, $message);
					
					if($success) {
						echo '<p>'.$i18n['EMAILUSERSEND'].'</p>';
						
					}
					else {
						echo '<p>'.$i18n['EMAILFAILURE'].'</p>';
					}
					
					$showForm = false;
				}
				else {
					echo '<p>'.$i18n['EMAILUNKNOWN'].'</p>';
				}
			}
		}
		
		if($showForm) {
			?>
			<h2 class="register_h2"><?php echo $i18n['FORGOTUSER'];?></h2>
			<p></p>
			<form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" name="forgotuserform" id="forgotuserform">
				<p><?php echo $i18n['FORGOTUSERTXT']; ?></p>
				<p>
					<label for="emailforgotuser" class="required" ><?php echo $i18n['EMAIL'];?></label>
					<input type="text" required name="emailforgotuser" id="emailforgotuser" />
				</p>
				<p>
					<input type="submit" name="forgotpass" id="forgotpass" value="<?php echo $i18n['SEND'];?>" />
					<input type="hidden" name="forgotuser-form" value="yes" />
				</p>
			</form>

			<?php
		}
	}
}

function user_forgot_password($i18n) {
  	$showForm = true;
  	global $SITEURL;
  	
  	//If User Is Not Logged In
	if(!isset($_SESSION['LoggedIn']))
	{
		if(isset($_POST['forgotpass-form']))
		{
			if(isset($_POST['emailforgotpass']))
			{
				$user = getUserForEmail($_POST['emailforgotpass']);
				
				if(strlen($user) > 0) {
					if(!is_dir(RESETPASSWORDPATH)) {
						mkdir(RESETPASSWORDPATH);
					}
					
					$createId = true;
					
					do {
						$id = createPwId(24);
						$file = RESETPASSWORDPATH.$id;
						
						if(is_file($file)) {
							$temp = getXML($file);
							
							if(isset($temp->Time)) {
								$diff = (int) time() - intval($temp->Time);
								
								if($diff > 21600) {
									unlink($file);
									$createId = false;
								}
							}
							else {
								unlink($file);
								$createId = false;
							}
						}
						else {
							$createId = false;
						}
					} while($createId);
					
					$xml = new SimpleXMLElement('<item></item>');
					
					$xml->addChild('User', $user);
					$xml->addChild('Time', time());
					
					XMLsave($xml, $file);
					
					//Send Email
					$to  = $_POST['emailforgotpass'];

					// subject
					$subject = 'You requested to change your password for '.$SITEURL;

					// message
					$message = "Hello ".$user.",\n\nYou've requested a password change. If you didn't you can simply ignore this email.\n\nTo change your password follow the following link:\nhttp://".$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'];
					
					if(strrpos($_SERVER['REQUEST_URI'],'?') !== false) {
						$message .= '&changePW='.$id;
					}
					else {
						$message .= '?changePW='.$id;
					}

					// Mail it
					$success = mail($to, $subject, $message);
					
					if($success) {
						echo '<p>'.$i18n['EMAILPASSSEND'].'</p>';
						
					}
					else {
						echo '<p>'.$i18n['EMAILFAILURE'].'</p>';
					}
					
					$showForm = false;
				}
				else {
					echo '<p>'.$i18n['EMAILUNKNOWN'].'</p>';
				}
			}
		}
		
		if($showForm) {
			?>
			<h2 class="register_h2"><?php echo $i18n['FORGOTPASS'];?></h2>
			<p></p>
			<form method="post" action="<?php echo $_SERVER['REQUEST_URI']; ?>" name="forgotpassform" id="forgotpassform">
				<p><?php echo $i18n['FORGOTPASSTXT']; ?></p>
				<p>
					<label for="emailforgotpass" class="required" ><?php echo $i18n['EMAIL'];?></label>
					<input type="text" required name="emailforgotpass" id="emailforgotpass" />
				</p>
				<p>
					<input type="submit" name="forgotpass" id="forgotpass" value="<?php echo $i18n['SEND'];?>" />
					<input type="hidden" name="forgotpass-form" value="yes" />
				</p>
			</form>

			<?php
		}
	}
}

function createPwId($length) {
        $characters = '0123456789';
        $characters .= 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
        $charactersLength = strlen($characters)-1;
        $id = '';

        //select some random characters
        for ($i = 0; $i < $length; $i++) {
            $id .= $characters[mt_rand(0, $charactersLength)];
        }       
       
        return $id;
}

//Displays group selection in edit.php
function user_login_edit()
{
	$Feul = new Feul;
	$access = $Feul->getAccessForPage();
	
	?>
		<div class="leftopt" style="margin-top:20px;">
			<p class="inline">
				<label for="member-only">Front end access control:</label> 
				<select class="text" id="member-only" name="member-only[]" type="text" multiple size=4>
					<?php
						foreach($Feul->getAllGroupNames() as $group) {
							echo '<option ';
							
							foreach($access as $accessGroups) {
								if($group == $accessGroups) {
									echo ' selected';
								}
							}
							
							echo '>'.$group.'</option>';
						}
					?>
				</select>
			</p>
		</div> 
	<?php
}

//Saves Value Of Checkbox in function - user_login_edit()
function user_login_save()
{
	global $xml;
	if(isset($_POST['member-only']))
	{ 
		$groups = "";
			
		foreach($_POST['member-only'] as $selectedGroup) {
			$groups = $groups.$selectedGroup.';';
		}
		
		if(strlen(trim($groups)) == 0) {
			$groups = "Unauthorized";
		}
		else {
			$groups = trim(substr($groups,0,strlen($groups)-1));
		}
	
		$node = $xml->addChild(strtolower('memberonly'))->addCData(stripslashes($groups));	
	}
}
